==> currents-api-types-0.0.77.tgz: package/subscription/parsers.ts <==
import z from 'zod';
import { SUBSCRIPTION_ID_PARAM_NAME, SUBSCRIPTION_STATUSES } from './constants';
import type { ApiSubscription } from './types';
import { cast } from '../utils/types';
import type { ListResponseTrait } from '../response/types';
import { stripeSubscriptionIdParser } from '../stripe/parsers';
import {
  payinAmountUnitParser,
  payinApiAmountParser,
  payinApiSrcDstCompositeParser,
  payinListQueryParser,
} from '../payin/parsers';
import { PAYIN_ORIGIN_TYPES } from '../payin/constants';
import { ApiSubscriptionWithProceedContext } from './types';
import { idempotencyKeyBodyParser } from '../idempotency/parser';

export const subscriptionListQueryParser = payinListQueryParser;

export const subscriptionListResponseParser = z.any(/*stub*/).transform((r) => r as ListResponseTrait<ApiSubscription>);
export const subscriptionGetOneParamsParser = z.object({
  [SUBSCRIPTION_ID_PARAM_NAME]: stripeSubscriptionIdParser,
});
export const subscriptionRecurringParser = z.boolean();
export const subscriptionStatusParser = z.enum(SUBSCRIPTION_STATUSES);
export const subscriptionApiRecurringParser = z.object({
  recurring: subscriptionRecurringParser,
});
export const subscriptionRecurringAndStatusParser = z
  .object({
    status: subscriptionStatusParser,
  })
  .merge(subscriptionApiRecurringParser);
export const subscriptionOriginTypeParser = z.enum(PAYIN_ORIGIN_TYPES);
// "api" subscription shape; not for use to parse real stripe subscriptions
export const subscriptionCreateInputParser = z
  .object({
    // // TODO camelcase; used?
    // origin_type: subscriptionOriginTypeParser,
    // // TODO camelcase; used?
    // origin_id: subscriptionOriginIdParser,
  })
  .merge(payinApiSrcDstCompositeParser)
  .merge(payinAmountUnitParser)
  .merge(subscriptionApiRecurringParser)
  .merge(idempotencyKeyBodyParser);
export const subscriptionCreateResponseParser = z.any(/*stub*/).transform(cast<ApiSubscriptionWithProceedContext>());

export const subscriptionUpdateInputParser = payinApiAmountParser.partial().merge(idempotencyKeyBodyParser);
export const subscriptionUpdateParamsParser = subscriptionGetOneParamsParser;
export const subscriptionUpdateResponseParser = subscriptionCreateResponseParser;
export const subscriptionDeleteParamsParser = subscriptionGetOneParamsParser;

==> currents-api-types-0.0.84.tgz: package/subscription/parsers.ts <==
import z from 'zod';
import { SUBSCRIPTION_ID_PARAM_NAME, SUBSCRIPTION_STATUSES } from './constants';
import type { ApiSubscription } from './types';
import { cast } from '../utils/types';
import type { ListResponseTrait } from '../response/types';
import { stripeSubscriptionIdParser } from '../stripe/parsers';
import {
  payinAmountUnitParser,
  payinApiAmountParser,
  payinApiSrcDstCompositeParser,
  payinListQueryParser,
} from '../payin/parsers';
import { PAYIN_ORIGIN_TYPES } from '../payin/constants';
import type { ApiSubscriptionWithProceedContext } from './types';
import { idempotencyKeyBodyParser } from '../idempotency/parser';

export const subscriptionListQueryParser = payinListQueryParser;

export const subscriptionListResponseParser = z.any(/*stub*/).transform((r) => r as ListResponseTrait<ApiSubscription>);
export const subscriptionGetOneParamsParser = z.object({
  [SUBSCRIPTION_ID_PARAM_NAME]: stripeSubscriptionIdParser,
});
export const subscriptionRecurringParser = z.boolean();
export const subscriptionStatusParser = z.enum(SUBSCRIPTION_STATUSES);
export const subscriptionApiRecurringParser = z.object({
  recurring: subscriptionRecurringParser,
});
export const subscriptionRecurringAndStatusParser = z
  .object({
    status: subscriptionStatusParser,
  })
  .merge(subscriptionApiRecurringParser);
export const subscriptionOriginTypeParser = z.enum(PAYIN_ORIGIN_TYPES);
// "api" subscription shape; not for use to parse real stripe subscriptions
export const subscriptionCreateInputParser = z
  .object({
    // // TODO camelcase; used?
    // origin_type: subscriptionOriginTypeParser,
    // // TODO camelcase; used?
    // origin_id: subscriptionOriginIdParser,
  })
  .merge(payinApiSrcDstCompositeParser)
  .merge(payinAmountUnitParser)
  .merge(subscriptionApiRecurringParser)
  .merge(idempotencyKeyBodyParser);
export const subscriptionCreateResponseParser = z.any(/*stub*/).transform(cast<ApiSubscriptionWithProceedContext>());

export const subscriptionUpdateInputParser = payinApiAmountParser.partial().merge(idempotencyKeyBodyParser);
export const subscriptionUpdateParamsParser = subscriptionGetOneParamsParser;
export const subscriptionUpdateResponseParser = subscriptionCreateResponseParser;
export const subscriptionDeleteParamsParser = subscriptionGetOneParamsParser;
